/****************************************************************************
** Meta object code from reading C++ file 'release.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-welcome-6.7.2/src/release.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'release.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7ReleaseE_t {};
} // unnamed namespace

template <> constexpr inline auto Release::qt_create_metaobjectdata<qt_meta_tag_ZN7ReleaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Release",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "previewStatusChanged",
        "",
        "previewErrorChanged",
        "previewErrorCodeChanged",
        "previewTitleChanged",
        "previewDescriptionChanged",
        "tryAutomaticPreview",
        "getPreview",
        "friendlyVersion",
        "isBeta",
        "isDevelopment",
        "announcementUrl",
        "previewStatus",
        "PreviewStatus",
        "previewError",
        "PreviewError",
        "previewErrorCode",
        "previewTitle",
        "previewDescription",
        "ReleaseType",
        "Shipping",
        "Beta",
        "Development",
        "Unloaded",
        "Loading",
        "Loaded",
        "None",
        "Metered",
        "NetworkCode",
        "ParseFailure"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'previewStatusChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewErrorChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewErrorCodeChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewTitleChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewDescriptionChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'tryAutomaticPreview'
        QtMocHelpers::MethodData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'getPreview'
        QtMocHelpers::MethodData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'friendlyVersion'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isBeta'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isDevelopment'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'announcementUrl'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'previewStatus'
        QtMocHelpers::PropertyData<enum PreviewStatus>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'previewError'
        QtMocHelpers::PropertyData<enum PreviewError>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'previewErrorCode'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'previewTitle'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'previewDescription'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ReleaseType'
        QtMocHelpers::EnumData<enum ReleaseType>(24, 24, QMC::EnumFlags{}).add({
            {   25, ReleaseType::Shipping },
            {   26, ReleaseType::Beta },
            {   27, ReleaseType::Development },
        }),
        // enum 'PreviewStatus'
        QtMocHelpers::EnumData<enum PreviewStatus>(18, 18, QMC::EnumFlags{}).add({
            {   28, PreviewStatus::Unloaded },
            {   29, PreviewStatus::Loading },
            {   30, PreviewStatus::Loaded },
        }),
        // enum 'PreviewError'
        QtMocHelpers::EnumData<enum PreviewError>(20, 20, QMC::EnumFlags{}).add({
            {   31, PreviewError::None },
            {   32, PreviewError::Metered },
            {   33, PreviewError::NetworkCode },
            {   34, PreviewError::ParseFailure },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Release, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Release::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ReleaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ReleaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7ReleaseE_t>.metaTypes,
    nullptr
} };

void Release::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Release *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->previewStatusChanged(); break;
        case 1: _t->previewErrorChanged(); break;
        case 2: _t->previewErrorCodeChanged(); break;
        case 3: _t->previewTitleChanged(); break;
        case 4: _t->previewDescriptionChanged(); break;
        case 5: _t->tryAutomaticPreview(); break;
        case 6: _t->getPreview(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Release::*)()>(_a, &Release::previewStatusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Release::*)()>(_a, &Release::previewErrorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Release::*)()>(_a, &Release::previewErrorCodeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Release::*)()>(_a, &Release::previewTitleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Release::*)()>(_a, &Release::previewDescriptionChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_friendlyVersion; break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBeta(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isDevelopment(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->announcementUrl(); break;
        case 4: *reinterpret_cast<enum PreviewStatus*>(_v) = _t->m_previewStatus; break;
        case 5: *reinterpret_cast<enum PreviewError*>(_v) = _t->m_previewError; break;
        case 6: *reinterpret_cast<int*>(_v) = _t->m_previewErrorCode; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->m_previewTitle; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->m_previewDescription; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4:
            if (QtMocHelpers::setProperty(_t->m_previewStatus, *reinterpret_cast<enum PreviewStatus*>(_v)))
                Q_EMIT _t->previewStatusChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_previewError, *reinterpret_cast<enum PreviewError*>(_v)))
                Q_EMIT _t->previewErrorChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_previewErrorCode, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->previewErrorChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_previewTitle, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->previewTitleChanged();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_previewDescription, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->previewDescriptionChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *Release::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Release::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ReleaseE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Release::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Release::previewStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Release::previewErrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Release::previewErrorCodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Release::previewTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Release::previewDescriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
