/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<app.h>)
#  include <app.h>
#endif
#if __has_include(<plasmacolors.h>)
#  include <plasmacolors.h>
#endif
#if __has_include(<qmlconfig.h>)
#  include <qmlconfig.h>
#endif
#if __has_include(<release.h>)
#  include <release.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_welcome_private()
{
    qmlRegisterModule("org.kde.plasma.welcome.private", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<App>("org.kde.plasma.welcome.private", 254);
    qmlRegisterEnum<App::Mode>("App::Mode");
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    qmlRegisterTypesAndRevisions<PlasmaColors>("org.kde.plasma.welcome.private", 254);
    qmlRegisterTypesAndRevisions<QmlConfig>("org.kde.plasma.welcome.private", 254);
    qmlRegisterTypesAndRevisions<Release>("org.kde.plasma.welcome.private", 254);
    qmlRegisterEnum<Release::ReleaseType>("Release::ReleaseType");
    qmlRegisterEnum<Release::PreviewStatus>("Release::PreviewStatus");
    qmlRegisterEnum<Release::PreviewError>("Release::PreviewError");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.welcome.private", 254, 254);
}

static const QQmlModuleRegistration orgkdeplasmawelcomeprivateRegistration("org.kde.plasma.welcome.private", qml_register_types_org_kde_plasma_welcome_private);
