/****************************************************************************
** Meta object code from reading C++ file 'config.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../config.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'config.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6ConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto Config::qt_create_metaobjectdata<qt_meta_tag_ZN6ConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Config",
        "LastSeenVersionChanged",
        "",
        "LiveEnvironmentChanged",
        "LiveInstallerChanged",
        "ShowUpdatePageChanged",
        "AutomaticUpdatePreviewChanged",
        "lastSeenVersion",
        "isLastSeenVersionImmutable",
        "liveEnvironment",
        "isLiveEnvironmentImmutable",
        "defaultLiveEnvironmentValue",
        "liveInstaller",
        "isLiveInstallerImmutable",
        "showUpdatePage",
        "isShowUpdatePageImmutable",
        "defaultShowUpdatePageValue",
        "automaticUpdatePreview",
        "isAutomaticUpdatePreviewImmutable",
        "defaultAutomaticUpdatePreviewValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'LastSeenVersionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LiveEnvironmentChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LiveInstallerChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowUpdatePageChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutomaticUpdatePreviewChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lastSeenVersion'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isLastSeenVersionImmutable'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'liveEnvironment'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isLiveEnvironmentImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLiveEnvironmentValue'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'liveInstaller'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isLiveInstallerImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showUpdatePage'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isShowUpdatePageImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowUpdatePageValue'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'automaticUpdatePreview'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isAutomaticUpdatePreviewImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutomaticUpdatePreviewValue'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Config, qt_meta_tag_ZN6ConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Config::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6ConfigE_t>.metaTypes,
    nullptr
} };

void Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Config *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->LastSeenVersionChanged(); break;
        case 1: _t->LiveEnvironmentChanged(); break;
        case 2: _t->LiveInstallerChanged(); break;
        case 3: _t->ShowUpdatePageChanged(); break;
        case 4: _t->AutomaticUpdatePreviewChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::LastSeenVersionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::LiveEnvironmentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::LiveInstallerChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::ShowUpdatePageChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::AutomaticUpdatePreviewChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->lastSeenVersion(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isLastSeenVersionImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->liveEnvironment(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isLiveEnvironmentImmutable(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->defaultLiveEnvironmentValue(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->liveInstaller(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isLiveInstallerImmutable(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->showUpdatePage(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isShowUpdatePageImmutable(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->defaultShowUpdatePageValue(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->automaticUpdatePreview(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isAutomaticUpdatePreviewImmutable(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->defaultAutomaticUpdatePreviewValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLastSeenVersion(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setLiveEnvironment(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setLiveInstaller(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setShowUpdatePage(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setAutomaticUpdatePreview(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Config::LastSeenVersionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Config::LiveEnvironmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Config::LiveInstallerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Config::ShowUpdatePageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Config::AutomaticUpdatePreviewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
